****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_restricttoencounter.sas  
*
* Created (mm/dd/yyyy): 03/01/2018
* Last modified:
* Version: 1.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
* 	This program will identify claims occuring during reference encounter 
*
*  Program inputs:                                                                                   
* 	-Dataset containing the encounter that claims must occur during         
*	-Dataset containing the claims that must occur during the encounter
*
*  Program outputs:                                                                                                                                       
*  	-Dataset containing the resultant claims
* 
* PARAMETERS:
*  	-encfile		= Dataset containing the encounters that claims must overlap
*   -claimfile		= Dataset containing the claims that must occur during the encounter
*   -outfile		= Output dataset containing the resultant claims
*
*  Programming Notes:                                                                                
*                                                                           
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials	   Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*             mm/dd/yy
*
***************************************************************************************************;

%macro ms_restricttoencounter(encfile=,
                       		  claimfile=,
                       		  outfile=);

    %put =====> MACRO CALLED: ms_restricttoencounter v1.0;

	proc sql noprint undo_policy=none;
		create table &outfile. as
		select claim.*,
			   enc.adate as enc_start,
			   enc.ddate as enc_end,
			   enc.discharge_disposition,
			   enc.facility_code,
			   enc.enctype
		from &claimfile. as claim,
		&encfile. as enc
		where claim.patid = enc.patid and claim.encounterID = enc.encounterID;
	quit;

    %put NOTE: ********END OF MACRO: ms_restricttoencounter v1.0********;

%mend ms_restricttoencounter;
